@@ -12,7 +12,6 @@ from __future__ import print_function
 import pandas as pd
 import numpy as np
 from sklearn import metrics
-import json
 
 # pdkit imports
 import pdkit
@@ -75,13 +74,6 @@ class GaitFeaturize:
                                                     measured in Hz
                                                     default: 3-8Hz
         sampling_frequency (dtype: float, int)    : Samples per seconds
-
-    HOW-TO-USE:
-        import utils.gait_features_utils
-        sensor_data =  (options of pd.DataFrame or string filepath)
-        gf          =  gait_features_utils.GaitFeaturize()
-        features    =  gf.run_gait_feature_pipeline(sensor_data)
-
     """
 
     def __init__(self,
@@ -96,9 +88,7 @@ class GaitFeaturize:
                  window_overlap=0.2,
                  loco_band=[0.5, 3],
                  freeze_band=[3, 8],
-                 sampling_frequency=100,
-                 time_offset=[0, 30]
-                 ):
+                 sampling_frequency=100):
         self.rotation_frequency_cutoff = rotation_frequency_cutoff
         self.rotation_filter_order = rotation_filter_order
         self.rotation_aucXt_upper_limit = rotation_aucXt_upper_limit
@@ -111,66 +101,6 @@ class GaitFeaturize:
         self.loco_band = loco_band
         self.freeze_band = freeze_band
         self.sampling_frequency = sampling_frequency
-        self.time_offset = time_offset
-
-    def get_sensor_data(self, data, sensor):
-        """
-        Utility Function to get sensor data given a filepath or a dataframe.
-        Data extraction will be adjusted to several different key-value format
-        of sensor data json files
-
-        Args:
-            data     (dtype: string, pd.DataFrame): filepath or dataframe
-            sensor   (dtype: string)              : sensor type
-
-        Returns:
-            Rtype: pd.DataFrame, or string error messages
-            Return a formatted version of the dataframe that contains formatted
-            time-series of sensor data or error message
-
-        Return Column Format:
-            [timestamp (DateTimeIndexindex), x, y, z, AA, td]
-        """
-
-        if isinstance(data, (type(None), type(np.NaN))):
-            return "ERROR: Empty Filepath"
-        try:
-            if isinstance(data, str):
-                with open(data) as f:
-                    json_data = f.read()
-                    data = pd.DataFrame(json.loads(json_data))
-
-            # empty dataframe can be caused by two things:
-            # key is not available or an empty dataframe itself,
-            # catch key error if sensor is not available
-            if not data.empty:
-                if ("sensorType" in data.columns):
-                    data = data[data["sensorType"] == sensor]
-                    if data.empty:
-                        raise KeyError
-                else:
-                    data = data[["timestamp", sensor]]
-                    data["x"] = data[sensor].apply(lambda x: x["x"])
-                    data["y"] = data[sensor].apply(lambda x: x["y"])
-                    data["z"] = data[sensor].apply(lambda x: x["z"])
-                    data = data.drop([sensor], axis=1)
-        # exceptions during data reading
-        except (AttributeError, TypeError,
-                FileNotFoundError, MemoryError, KeyError) as err:
-            return "ERROR: %s" % type(err).__name__
-        else:
-            # check if empty
-            if data.empty:
-                return "ERROR: Filepath has Empty Dataframe"
-            elif not (set(data.columns) >= set(["x", "y", "z", "timestamp"])):
-                return "ERROR: [timestamp, x, y, z] in columns is required"
-            else:
-                data = self.format_time_series_data(data)
-            if ((data["td"].iloc[-1] > self.time_offset[1])
-                    & (data["td"].iloc[0] <= self.time_offset[0])):
-                return "ERROR: Exceeded Time Offset"
-            else:
-                return data
 
     def format_time_series_data(self, data):
         """
@@ -202,7 +132,27 @@ class GaitFeaturize:
         data = data[~data.index.duplicated(keep='first')]
         return data[["td", "x", "y", "z", "AA"]]
 
-    def _calculate_freeze_index(self, accel_series, sample_rate):
+    def format_mpower_ts(self, data):
+        """
+        Function to format mPower Dataframe after subselecting
+        which sensor types it tries to query
+        Args:
+            data (dtype: dataframe): dataframe time-series
+        Returns:
+            returns a cleaned and resampled sensor dataframe
+        """
+        try:
+            if data.empty:
+                return "ERROR: Filepath has Empty Dataframe"
+            elif not (set(data.columns) >= set(["x", "y", "z", "timestamp"])):
+                return "ERROR: [timestamp, x, y, z] in columns is required"
+            else:
+                data = self.format_time_series_data(data)
+            return self.resample_signal(data)
+        except(TypeError, AttributeError) as err:
+            return "ERROR: %s" % type(err).__name__
+
+    def calculate_freeze_index(self, accel_series, sample_rate):
         """
         Modified pdkit FoG freeze index function to be compatible with
         current data gait pipeline
@@ -228,11 +178,8 @@ class GaitFeaturize:
             f_nr_FBs = int(freeze_band[0] / f_res)
             f_nr_FBe = int(freeze_band[1] / f_res)
 
-            # normalize series
-            normalized_accel_series = accel_series - np.mean(accel_series)
-
             # discrete fast fourier transform
-            Y = np.fft.fft(normalized_accel_series, int(window_size))
+            Y = np.fft.fft(accel_series, int(window_size))
             Pyy = abs(Y*Y) / window_size
             areaLocoBand = numerical_integration(
                 Pyy[f_nr_LBs-1: f_nr_LBe],   sample_rate)
@@ -532,7 +479,7 @@ class GaitFeaturize:
 
             speed_of_gait = gp.speed_of_gait(series, wavelet_level=6)
             energy_freeze_index, \
-                locomotor_freeze_index = self._calculate_freeze_index(
+                locomotor_freeze_index = self.calculate_freeze_index(
                     series, self.sampling_frequency)
             feature_dict["%s_energy_freeze_index" % axis] = energy_freeze_index
             feature_dict["%s_loco_freeze_index" %
@@ -609,27 +556,3 @@ class GaitFeaturize:
         except Exception as err:
             result["error"] = [err]
             return result
-
-    def format_mpower_ts(self, data):
-        """
-        Function to format mPower Dataframe after subselecting
-        which sensor types it tries to query
-        Args:
-            data (dtype: dataframe): dataframe time-series
-        Returns:
-            returns a cleaned and resampled sensor dataframe
-        """
-        try:
-            if data.empty:
-                return "ERROR: Filepath has Empty Dataframe"
-            elif not (set(data.columns) >= set(["x", "y", "z", "timestamp"])):
-                return "ERROR: [timestamp, x, y, z] in columns is required"
-            else:
-                data = self.format_time_series_data(data)
-            if ((data["td"].iloc[-1] > self.time_offset[1])
-                    & (data["td"].iloc[0] <= self.time_offset[0])):
-                return "ERROR: Exceeded Time Offset"
-            else:
-                return self.resample_signal(data)
-        except(TypeError, AttributeError) as err:
-            return "ERROR: %s" % type(err).__name__
